@@ -2,12 +2,11 @@
 use proc_macro::TokenStream;
 use syn::parse_macro_input;
 use quote::quote;
-
-mod frac;
+use const_frac::frac::syn:: { TokenFrac, ClonedPath };
 
 #[proc_macro]
 pub fn frac(input: TokenStream) -> TokenStream {
-    let result = parse_macro_input!(input as frac::Frac);
+    let result = parse_macro_input!(input as TokenFrac<ClonedPath>);
 
     quote! { #result }.into()
 }
